@@ -1,11 +1,12 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-GLUT-2.5.1.1/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: GLUT
-version: 2.4.0.0
-id: GLUT-2.4.0.0-233c0126d396c5b3c1eaeef53e45e2a3
+version: 2.5.1.1
+id: GLUT-2.5.1.1-86b47e0dad63df8c5d8772ec45637472
 
 license: BSD3
 copyright:
-maintainer: Jason Dagit <dagitj@gmail.com>
+maintainer: Sven Panne <svenpanne@gmail.com>, Jason Dagit <dagitj@gmail.com>
 stability:
 homepage: http://www.haskell.org/haskellwiki/Opengl
 package-url:
@@ -26,30 +27,29 @@ exposed-modules: Graphics.UI.GLUT Graphics.UI.GLUT.Begin
                  Graphics.UI.GLUT.Initialization Graphics.UI.GLUT.Menu
                  Graphics.UI.GLUT.Objects Graphics.UI.GLUT.Overlay
                  Graphics.UI.GLUT.State Graphics.UI.GLUT.Window
-                 Graphics.UI.GLUT.Callbacks.Registration Graphics.UI.GLUT.QueryUtils
-                 Graphics.UI.GLUT.Raw Graphics.UI.GLUT.Raw.APIEntry
-                 Graphics.UI.GLUT.Raw.Callbacks Graphics.UI.GLUT.Raw.Fonts
-                 Graphics.UI.GLUT.Raw.Functions Graphics.UI.GLUT.Raw.Tokens
-                 Graphics.UI.GLUT.Types
-hidden-modules:
+hidden-modules: Graphics.UI.GLUT.Callbacks.Registration
+                Graphics.UI.GLUT.QueryUtils Graphics.UI.GLUT.Raw
+                Graphics.UI.GLUT.Raw.APIEntry Graphics.UI.GLUT.Raw.Callbacks
+                Graphics.UI.GLUT.Raw.Fonts Graphics.UI.GLUT.Raw.Functions
+                Graphics.UI.GLUT.Raw.Tokens Graphics.UI.GLUT.Types
 trusted: False
-import-dirs: /usr/local/lib/ghc/GLUT-2.4.0.0
-library-dirs: /usr/local/lib/ghc/GLUT-2.4.0.0
-hs-libraries: HSGLUT-2.4.0.0
+import-dirs: /usr/local/lib/ghc/GLUT-2.5.1.1
+library-dirs: /usr/local/lib/ghc/GLUT-2.5.1.1
+hs-libraries: HSGLUT-2.5.1.1
 extra-libraries: glut
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: OpenGL-2.8.0.0-6c09a71eab62884ba1b0aba537b99b6b
-         OpenGLRaw-1.3.0.0-6f5bc80dc04e9b14fad26151d827173c
-         array-0.4.0.1-6380782b62ead58fec616aa07dc0e15c
-         base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
-         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
+depends: OpenGL-2.9.2.0-3866a603e05ac9db9ad02ebb2d799a36
+         OpenGLRaw-1.5.0.0-ecac437af724c8c90ed873a69fdf1787
+         array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-GLUT-2.4.0.0/html/GLUT.haddock
-haddock-html: /usr/local/share/doc/hs-GLUT-2.4.0.0/html
+haddock-interfaces: /usr/local/share/doc/hs-GLUT-2.5.1.1/html/GLUT.haddock
+haddock-html: /usr/local/share/doc/hs-GLUT-2.5.1.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
